@@ -14,6 +14,8 @@ class DbColumn:
     eid = 'eid'
     entrance = 'entrance'
     flow = 'flow'
+    flowin = 'flow_in'
+    flowout = 'flow_out'
     fluidity = 'fluidity'
     fromtraveltime = 'from_travel_time'
     fromroad = 'from_road'
